@@ -71,9 +71,10 @@ autoLogout = {{auto_logout}}
 
 [resources]
 openPortToPublic = {{open_port_to_public}}
-maxCPUCoresPerSession = {{max_cpu_cores_per_session}}
-maxCUDADevicesPerSession = {{max_cuda_devices_per_session}}
-maxShmPerSession = {{max_shm_per_session}}
+maxCPUCoresPerContainer = {{max_cpu_cores_per_container}}
+maxCUDADevicesPerContainer = {{max_cuda_devices_per_container}}
+maxCUDASharesPerContainer = {{max_cuda_shares_per_container}}
+maxShmPerContainer = {{max_shm_per_container}}
 maxFileUploadSize = {{max_file_upload_size}}
 
 [menu]
@@ -138,15 +139,19 @@ async def console_handler(request: web.Request) -> web.StreamResponse:
             license_valid_until = ''
         if 'resources' in config:
             open_port_to_public = 'true' if config['resources'].get('open_port_to_public') else 'false'
-            max_cpu_cores_per_session = config['resources'].get('max_cpu_cores_per_session', 64)
-            max_cuda_devices_per_session = config['resources'].get('max_cuda_devices_per_session', 16)
-            max_shm_per_session = config['resources'].get('max_shm_per_session', 2)
+            max_cpu_cores_per_container = config['resources'].get('max_cpu_cores_per_container', 64)
+            max_cuda_devices_per_container = config['resources'].get(
+                    'max_cuda_devices_per_container', 16)
+            max_cuda_shares_per_container = config['resources'].get(
+                    'max_cuda_shares_per_container', 16)
+            max_shm_per_container = config['resources'].get('max_shm_per_container', 2)
             max_file_upload_size = config['resources'].get('max_file_upload_size', 4294967296)
         else:
             open_port_to_public = 'false'
-            max_cpu_cores_per_session = 64
-            max_cuda_devices_per_session = 16
-            max_shm_per_session = 2
+            max_cpu_cores_per_container = 64
+            max_cuda_devices_per_container = 16
+            max_cuda_shares_per_container = 16
+            max_shm_per_container = 2
             max_file_upload_size = 4294967296
         config_content = console_config_toml_template.render(**{
             'endpoint_url': f'{scheme}://{request.host}',  # must be absolute
@@ -164,9 +169,10 @@ async def console_handler(request: web.Request) -> web.StreamResponse:
             'auto_logout':
                 'true' if config['service'].get('auto_logout') else 'false',
             'open_port_to_public': open_port_to_public,
-            'max_cpu_cores_per_session': max_cpu_cores_per_session,
-            'max_cuda_devices_per_session': max_cuda_devices_per_session,
-            'max_shm_per_session': max_shm_per_session,
+            'max_cpu_cores_per_container': max_cpu_cores_per_container,
+            'max_cuda_devices_per_container': max_cuda_devices_per_container,
+            'max_cuda_shares_per_container': max_cuda_shares_per_container,
+            'max_shm_per_container': max_shm_per_container,
             'max_file_upload_size': max_file_upload_size,
             'menu_blocklist': config['ui'].get('menu_blocklist', ''),
             'license_edition': license_edition,
